==> pre-commit-cairo-0.0.3.tar.gz: pre-commit-cairo-0.0.3/pre_commit_cairo/check_lint.py <==
from __future__ import annotations

import argparse
import subprocess
import json
from typing import Sequence

from rich.console import Console
from rich.table import Table

console = Console()


def _build_summary(info, filename):
    table_result = Table(title=filename)
    table_result.add_column("ruleId")
    table_result.add_column("level")
    table_result.add_column("message")

    table_result.add_row(info["ruleId"], info["level"], info["message"]["text"])

    table_location = Table(title="locations")
    table_location.add_column("uri")
    table_location.add_column("location_line")
    table_location.add_column("location_column_start")
    table_location.add_column("location_column_end")

    for location in info["locations"]:
        table_result.add_row(
            location["physicalLocation"]["artifactLocation"]["uri"],
            location["physicalLocation"]["region"]["startLine"],
            location["physicalLocation"]["region"]["startColumn"],
            location["physicalLocation"]["region"]["endColumn"],
        )


def main(argv: Sequence[str] | None = None) -> int:
    parser = argparse.ArgumentParser()
    parser.add_argument("filenames", nargs="*")
    args = parser.parse_args(argv)

    retval = 0
    for filename in args.filenames:
        if filename.endswith(".cairo"):
            try:
                subprocess.run(
                    f'amarna {filename} -o {filename.replace(".cairo", ".sarif")}',
                    shell=True,
                    universal_newlines=True,
                    check=True,
                )
            except subprocess.CalledProcessError as e:
                console.print(
                    f"[red][bold]{filename}]: failed linting check[/bold][/red]"
                )
                summary = json.load(filename.replace(".cairo", ".sarif"))
                for result in summary:
                    _build_summary(result, filename)
                retval = 1

    return retval


if __name__ == "__main__":
    raise SystemExit(main())

==> pre-commit-cairo-0.0.4.tar.gz: pre-commit-cairo-0.0.4/pre_commit_cairo/check_lint.py <==
from __future__ import annotations

import argparse
import subprocess
import json
from typing import Sequence

from rich.console import Console
from rich.table import Table

console = Console()


def _build_summary(info, filename):
    table_result = Table(title=filename)
    table_result.add_column("ruleId")
    table_result.add_column("level")
    table_result.add_column("message")

    table_result.add_row(info["ruleId"], info["level"], info["message"]["text"])

    table_location = Table(title="locations")
    table_location.add_column("uri")
    table_location.add_column("location_line")
    table_location.add_column("location_column_start")
    table_location.add_column("location_column_end")

    for location in info["locations"]:
        table_result.add_row(
            location["physicalLocation"]["artifactLocation"]["uri"],
            location["physicalLocation"]["region"]["startLine"],
            location["physicalLocation"]["region"]["startColumn"],
            location["physicalLocation"]["region"]["endColumn"],
        )


def main(argv: Sequence[str] | None = None) -> int:
    parser = argparse.ArgumentParser()
    parser.add_argument("filenames", nargs="*")
    args = parser.parse_args(argv)

    retval = 0
    for filename in args.filenames:
        if filename.endswith(".cairo"):
            try:
                subprocess.run(
                    f'amarna {filename} -o {filename.replace(".cairo", ".sarif")}',
                    shell=True,
                    universal_newlines=True,
                    check=True,
                )
            except subprocess.CalledProcessError:
                console.print(
                    f"[red][bold]{filename}]: failed linting check[/bold][/red]"
                )
                with open(filename.replace(".cairo", ".sarif"), "r") as f:
                    summary = json.load(f)
                for result in summary:
                    _build_summary(result, filename)
                retval = 1

    return retval


if __name__ == "__main__":
    raise SystemExit(main())
